==================
Model verification
==================

The ``heron`` package includes tools for verifying the output of a model against either other models or waveforms in a numerical relativity catalogue.

These allow the easy calculation of both in-sample and out-of-sample tests.

.. autoclass:: heron.testing
